pmx: alchemistry in gromacs
===========================

|build| |cov|

**Warning:** this is a development version of ``pmx`` (`commit b8d83d0 <https://github.com/deGrootLab/pmx/tree/b8d83d0679b9728057c6ac18a04c86cebed72b47>`_), it is not stable or reliable yet. You are welcome to
try/test it and provide feedback, but use at your own risk. The current stable version of ``pmx`` can
be found in the master branch: https://github.com/deGrootLab/pmx

``pmx`` is a python library that allows users to setup and analyse molecular
dynamics simulations with the `Gromacs <http://gromacs.org>`_ package.
Among its main features are the setup and analysis of alchemical free energy
calculations for protein, nucleic acid, and small molecule mutations.

https://degrootlab.github.io/pmx/

Citations
---------
``pmx`` is a research software. If you make use of it in scientific publications, please cite the following papers::

    @article{Gapsys2015pmx,
        title = {pmx: Automated protein structure and topology
        generation for alchemical perturbations},
        author = {Gapsys, Vytautas and Michielssens, Servaas
        and Seeliger, Daniel and de Groot, Bert L.},
        journal = {Journal of Computational Chemistry},
        volume = {36},
        number = {5},
        pages = {348--354},
        year = {2015},
        doi = {10.1002/jcc.23804}
    }

    @article{Seeliger2010pmx,
        title = {Protein Thermostability Calculations Using
        Alchemical Free Energy Simulations},
        author = {Seeliger, Daniel and de Groot, Bert L.},
        journal = {Biophysical Journal},
        volume = {98},
        number = {10},
        pages = {2309--2316},
        year = {2010},
        doi = {10.1016/j.bpj.2010.01.051}
    }


License
-------
``pmx`` is licensed under the GNU Lesser General Public License v3.0 (LGPL v3).

.. |build| image:: https://travis-ci.org/deGrootLab/pmx.svg?branch=master
    :alt: Build Status
    :target: https://travis-ci.org/deGrootLab/pmx

.. |cov| image:: https://codecov.io/gh/deGrootLab/pmx/branch/develop/graph/badge.svg
    :alt: Code coverage
    :target: https://codecov.io/gh/deGrootLab/pmx
